@@ -4,12 +4,10 @@ path <- file.path(tempdir(),'rmd')
 
 cleanup(path)
 
-rmarkdown::render('../assets/input/test_html.Rmd',
-                  output_dir = path, params = list(path = path),
-                  quiet = TRUE)
-
 testthat::describe('html',{
   
+  safe_render(input = '../assets/input/test_html.Rmd', output_dir = path, render_params = list(path = path), cran = TRUE, quiet = TRUE)
+    
   it('output device', {
     testthat::expect_true(file.exists(file.path(path,'test_html.html')))
   })
@@ -22,12 +20,8 @@ testthat::describe('html',{
 
 testthat::describe('pdf',{
 
-  testthat::skip_on_cran()
+  safe_render(input = '../assets/input/test_pdf.Rmd',output_dir = path, render_params = list(path = path), quiet = TRUE)
   
-  rmarkdown::render('../assets/input/test_pdf.Rmd',
-                    output_dir = path, params = list(path = path),
-                    quiet = TRUE)
-    
   it('output device', {
     testthat::expect_true(file.exists(file.path(path,'test_pdf.pdf')))
   })
